===========================
django-uploader v |version|
===========================

About
=====

Django Uploader uses `jQuery file upload`_ to allow drag-and-drop file upload of any file type in the Django Admin. Third-party applications to write handlers for specific file types, and register them with Django Uploader. When a file of that type is uploaded, it passes the information to the handler so that it can make a new record with that file.

.. _jQuery file upload: https://blueimp.github.io/jQuery-File-Upload/


Contents
========

.. toctree::
   :maxdepth: 2
   :glob:

   getting_started
   models
